@@ -54,8 +54,11 @@ class NameServer(object):
             raise pycom.BadRequest("Following field are mandatory: "
                 "address, interface, service")
 
+        if interface not in self._registry:
+            self._registry[interface] = []
+
         rec = _Record(address, interface, service)
-        self._registry[interface] = rec
+        self._registry[interface].append(rec)
         self._services[service] = rec
 
         return {}
@@ -70,15 +73,25 @@ class NameServer(object):
                 "interface")
 
         try:
-            record = self._registry[interface]
+            records = self._registry[interface]
         except KeyError:
             raise pycom.ServiceNotFound("Interface not found: %s" %
                 interface)
 
-        return {
-            "address": record.address,
-            "service": record.service
-        }
+        if request.args.get("as_list"):
+            return [
+                {
+                    "address": record.address,
+                    "service": record.service
+                }
+                for record in records
+            ]
+
+        else:
+            return {
+                "address": records[0].address,
+                "service": records[0].service
+            }
 
     @pycom.method(constants.NS_METHOD_LIST_SERVICES)
     def method_list_services(self, request):    # pylint: disable-msg=W0613
