@@ -26,13 +26,12 @@
 
 """Main routine implementation."""
 
-import logging
-
 import zmq
 from zmq import eventloop
 from six import iterkeys
 
-from . import conf, constants, exceptions, interfaces, nsclient, protocol
+from . import conf, constants, exceptions, interfaces, nsclient
+from . import protocol, utils
 
 
 def ioloop():
@@ -87,20 +86,31 @@ def _recv_ready(sock, events):  # pylint: disable-msg=W0613
     """Some messages are ready for reading."""
     while True:
         try:
-            cmd, body = sock.recv_multipart(flags=zmq.NOBLOCK)
-        except zmq.ZMQError as err:
-            if err.errno == zmq.EAGAIN:
-                return
-            else:
-                raise  # pragma: no cover
+            try:
+                request_parts = sock.recv_multipart(flags=zmq.NOBLOCK)
+            except zmq.ZMQError as err:
+                if err.errno == zmq.EAGAIN:
+                    return
+                else:
+                    raise  # pragma: no cover
 
-        # No use making this non-blocking - 0MQ cannot handle 2 reads at time
-        sock.send_multipart([constants.PROTO_STATUS_SUCCESS,
-            _process_call(cmd, body)])
+            utils.logger().debug("REQUEST %s", request_parts)
+
+            body = _process_call(request_parts)
+
+            utils.logger().debug("RESPONSE %s", body)
+
+            sock.send_multipart([constants.PROTO_STATUS_SUCCESS, body])
+        except:  # pragma: no cover
+            utils.logger().critical("EXCEPTION IN HANDLER",
+                exc_info=True)
+            sock.send_multipart([constants.PROTO_STATUS_FAILURE, ""])
 
 
-def _process_call(cmd, body):
+def _process_call(request_parts):
     """Process single remote call."""
+    cmd, body = request_parts
+
     if cmd != constants.PROTO_CMD_CALL:
         return protocol.response_to_wire(constants.ERROR_BAD_REQUEST,
             "Unknown command: %s" % cmd, None)
@@ -119,7 +129,7 @@ def _process_call(cmd, body):
     try:
         method_callable = service.__interface__.methods[request.method]
     except KeyError:
-        return protocol.response_to_wire(constants.ERROR_BAD_REQUEST,
+        return protocol.response_to_wire(constants.ERROR_METHOD_NOT_FOUND,
             "No method %s in interface %s" %
             (request.method, request.interface), None)
 
@@ -127,11 +137,9 @@ def _process_call(cmd, body):
         result = method_callable(service, request)
     except exceptions.Error as err:
         err_code = err.code or constants.ERROR_UNKNOWN
-        logging.error("FAILED CALL TO %s.%s WITH CODE %d: %s",
-            request.interface, request.method, err_code, str(err))
         return protocol.response_to_wire(err_code, str(err), None)
     except Exception as err:
-        logging.exception("FAILED CALL TO %s.%s",
+        utils.logger().exception("FAILED CALL TO %s.%s",
             request.interface, request.method)
         return protocol.response_to_wire(constants.ERROR_UNKNOWN,
             "Unknown error during request", None)
