@@ -53,6 +53,30 @@ class TestNameServer(unittest.TestCase):
         self.assertEqual(item.interface, "test_apps_nameserver.testRegisterOk")
         self.assertEqual(item.service, "/test_apps_nameserver/testRegisterOk")
         self.assertEqual(item.address, "null://null")
+        self.assertEqual(
+            len(self.service._registry["test_apps_nameserver.testRegisterOk"]),
+            1)
+
+    def testInterfaceReregisterOk(self):
+        self.assertEqual(self.invoker.invoke(constants.NS_METHOD_REGISTER,
+            args={
+                "interface": "test_apps_nameserver.testReregisterOk",
+                "service": "/test_apps_nameserver/testReregisterOk",
+                "address": "null://null"
+            }), {})
+        self.assertEqual(self.invoker.invoke(constants.NS_METHOD_REGISTER,
+            args={
+                "interface": "test_apps_nameserver.testReregisterOk",
+                "service": "/test_apps_nameserver/testReregisterOk2",
+                "address": "null://null"
+            }), {})
+        item = self.service._services["/test_apps_nameserver/testReregisterOk"]
+        self.assertEqual(item.interface, "test_apps_nameserver.testReregisterOk")
+        self.assertEqual(item.service, "/test_apps_nameserver/testReregisterOk")
+        self.assertEqual(item.address, "null://null")
+        self.assertEqual(
+            len(self.service._registry["test_apps_nameserver.testReregisterOk"]),
+            2)
 
     def testRegisterWOAddress(self):
         self.assertRaises(exceptions.BadRequest, self.invoker.invoke,
@@ -63,10 +87,11 @@ class TestNameServer(unittest.TestCase):
             })
 
     def testLocateOk(self):
-        self.service._registry["test_apps_nameserver.testLocateOk"] = \
+        self.service._registry["test_apps_nameserver.testLocateOk"] = [
             nameserver._Record("null://null",
                 "test_apps_nameserver.testLocateOk",
                 "/test_apps_nameserver/testLocateOk")
+        ]
         self.assertDictEqual(self.invoker.invoke(constants.NS_METHOD_LOCATE,
             args={
                 "interface": "test_apps_nameserver.testLocateOk"
@@ -75,11 +100,36 @@ class TestNameServer(unittest.TestCase):
                 "address": "null://null"
             })
 
+    def testLocateList(self):
+        self.service._registry["test_apps_nameserver.testLocateList"] = [
+            nameserver._Record("null://null",
+                "test_apps_nameserver.testLocateList",
+                "/test_apps_nameserver/testLocateList"),
+            nameserver._Record("null://null",
+                "test_apps_nameserver.testLocateList",
+                "/test_apps_nameserver/testLocateList2")
+        ]
+        self.assertListEqual(self.invoker.invoke(constants.NS_METHOD_LOCATE,
+            args={
+                "interface": "test_apps_nameserver.testLocateList",
+                "as_list": True
+            }), [
+                {
+                    "service": "/test_apps_nameserver/testLocateList",
+                    "address": "null://null"
+                },
+                {
+                    "service": "/test_apps_nameserver/testLocateList2",
+                    "address": "null://null"
+                }
+            ])
+
     def testLocateWOAddress(self):
-        self.service._registry["test_apps_nameserver.testLocateWOAddress"] = \
+        self.service._registry["test_apps_nameserver.testLocateWOAddress"] = [
             nameserver._Record("null://null",
                 "test_apps_nameserver.testLocateWOAddress",
                 "/test_apps_nameserver/testLocateWOAddress")
+        ]
         self.assertRaises(exceptions.BadRequest, self.invoker.invoke,
             constants.NS_METHOD_LOCATE,
             args={})
