@@ -26,14 +26,13 @@
 
 """Tests for pycom.launcher."""
 
-import logging
 import random
 import threading
 import time
 
 import pycom
 import pycom.apps.nameserver
-from pycom import conf, constants, invoke, nsclient
+from pycom import conf, constants, invoke, nsclient, utils
 from pycom.test.utils import unittest, Replacer
 from pycom.test.test_nsclient import BaseTest
 
@@ -46,11 +45,10 @@ class MainTest(BaseTest, unittest.TestCase):
         conf.configuration.clear()
         nsclient._nameserver = invoke.DirectInvoker(
             pycom.apps.nameserver.NameServer())
-        logging.disable(logging.ERROR)
 
     def tearDown(self):
-        logging.disable(logging.DEBUG)
-        conf.configuration = self.oldConf
+        conf.configuration.clear()
+        conf.configuration.update(self.oldConf)
         super(MainTest, self).tearDown()
 
     def testService(self):
@@ -96,12 +94,12 @@ class MainTest(BaseTest, unittest.TestCase):
         def _check(address, self):
             wrong_meth = meth + "/banana!"
             invoker = invoke.RemoteInvoker(address, iface)
-            with self.assertRaisesRegexp(pycom.RemoteError,
-                    "No method %s in interface %s" %
+            with self.assertRaisesRegexp(pycom.MethodNotFound,
+                    "Method '%s' not found in interface %s" %
                     (wrong_meth, iface)) as context:
                 invoker.invoke(wrong_meth)
             self.assertEqual(context.exception.code,
-                constants.ERROR_BAD_REQUEST)
+                constants.ERROR_METHOD_NOT_FOUND)
 
         self._testService(iface, meth, _testMethod, _check, self)
 
